{% extends "base.html" %}
{% block title %}404 | {{ config.title }}{% endblock title %}
{% block content %}
<div class="not-found">
    <h1>404</h1>
    <p>Page not found</p>
    <a href="{{ config.base_url }}" class="button">&larr; back home</a>
</div>
{% endblock content %}
